==> 1.3.0.tar.gz: lib/src/shared/widget/control_panel.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:healthrian_visualization_support/'
    'healthrian_visualization_support.dart';

part 'control_panel.g.dart';

_$ControlPanelCWProxy get ControlPanelWearEcg =>
    ControlPanel(module: BLEManager().wearEcg12.module).copyWith;

_$ControlPanelCWProxy get ControlPanelCardioClick =>
    ControlPanel(module: BLEManager().cardioClick.module).copyWith;

_$ControlPanelCWProxy get ControlPanelWearT =>
    ControlPanel(module: BLEManager().wearCardioT.module).copyWith;

@CopyWith()
class ControlPanel extends StatelessWidget {
  const ControlPanel({
    required this.module,
    super.key,
  });

  final ModuleInterface module;

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          onPressed: () async {
            await module.ble.connectDevice();
            await module.ble.registerCharacteristics();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await module.ecg?.start();
            await module.oxi?.start();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await module.ecg?.pause();
            await module.oxi?.pause();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await module.ecg?.stop();
            await module.oxi?.stop();
            module.ecg?.initStream();
            module.oxi?.initStream();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () {
            module.ble.disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}

==> 1.9.12.tar.gz: lib/src/shared/widget/control_panel.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:healthrian_visualization_support/'
    'healthrian_visualization_support.dart';

part 'control_panel.g.dart';

_$ControlPanelCWProxy get ControlPanelWearEcg =>
    ControlPanel(module: BLEManager().wearEcg12.module).copyWith;

_$ControlPanelCWProxy get ControlPanelCardioClick =>
    ControlPanel(module: BLEManager().cardioClick.module).copyWith;

_$ControlPanelCWProxy get ControlPanelWearT =>
    ControlPanel(module: BLEManager().wearCardioT.module).copyWith;

@CopyWith()
class ControlPanel extends StatelessWidget {
  const ControlPanel({
    required this.module,
    super.key,
  });

  final ModuleInterface module;

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          onPressed: () async {
            await module.ble.connectAndRegister();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await module.ecg?.start();
            await module.oxi?.start();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await module.ecg?.pause();
            await module.oxi?.pause();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await module.ecg?.stop();
            await module.oxi?.stop();
            module.ecg?.initStream();
            module.oxi?.initStream();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () {
            module.ble.disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}
